@@ -58,10 +58,10 @@
 #include <QTemporaryFile>
 
 #ifdef HAVE_KWORKSPACE
-    #include <QDBusConnection>
-            #include <kworkspace/kworkspace.h>
-    #include <solid/powermanagement.h>
-#include <QStandardPaths>
+#include <QDBusConnection>
+#include <QDBusMessage>
+#include <QDBusPendingCall>
+#include <kworkspace.h>
 #endif
 
 
@@ -1555,21 +1555,21 @@ void GenericObserver::slotAfterFinishAction()
                         KWorkSpace::ShutdownModeForceNow);
             break;
         case KGet::Hibernate: {
-           QDBusMessage call;
-           call = QDBusMessage::createMethodCall("org.kde.Solid.PowerManagement",
-                                                 "/org/kde/Solid/PowerManagement",
-                                                 "org.kde.Solid.PowerManagement",
-                                                 "suspendToRam");
-           QDBusConnection::sessionBus().asyncCall(call);
+            QDBusMessage call;
+            call = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.PowerManagement"),
+                                                  QStringLiteral("/org/freedesktop/PowerManagement"),
+                                                  QStringLiteral("org.freedesktop.PowerManagement"),
+                                                  QStringLiteral("Hibernate"));
+            QDBusConnection::sessionBus().asyncCall(call);
             break;
         }
         case KGet::Suspend: {
-           QDBusMessage call;
-           call = QDBusMessage::createMethodCall("org.kde.Solid.PowerManagement",
-                                                 "/org/kde/Solid/PowerManagement",
-                                                 "org.kde.Solid.PowerManagement",
-                                                 "suspendToDisk");
-           QDBusConnection::sessionBus().asyncCall(call);
+            QDBusMessage call;
+            call = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.PowerManagement"),
+                                                  QStringLiteral("/org/freedesktop/PowerManagement"),
+                                                  QStringLiteral("org.freedesktop.PowerManagement"),
+                                                  QStringLiteral("Suspend"));
+            QDBusConnection::sessionBus().asyncCall(call);
             break;
         }
     #endif
